**Example 1: 漏洞管理 -应急漏洞检测**

漏洞管理 - 应急漏洞检测

Input: 

```
tccli cwp CreateEmergencyVulScan --cli-unfold-argument  \
    --VulId 1
```

Output: 
```
{
    "Response": {
        "RequestId": "42342314"
    }
}
```

